@@ -5,16 +5,29 @@ use warnings;
 use base 'Pod::Perldoc';
 use HTTP::Tiny;
 use File::Temp 'tempfile';
+use JSON ();
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
+
+sub opt_c { shift->_elem('opt_c', @_) }
 
 sub live_cpan_url {
     my $self   = shift;
     my $module = shift;
 
-    if ($self->opt_m) {
+    if ($self->opt_c) {
+        my $module_json = $self->fetch_url("http://api.metacpan.org/module/$module");
+        if (!$module_json) {
+            die "Unable to fetch changes for $module";
+        }
+        my $module_details = JSON::decode_json($module_json);
+        my $dist = $module_details->{distribution};
+        return "http://api.metacpan.org/v0/changes/$dist";
+    }
+    elsif ($self->opt_m) {
         return "http://api.metacpan.org/source/$module";
-    } else {
+    }
+    else {
         return "http://api.metacpan.org/pod/$module?content-type=text/x-pod";
     }
 }
@@ -54,7 +67,14 @@ sub query_live_cpan_for {
     my $module = shift;
 
     my $url = $self->live_cpan_url($module);
-    return $self->fetch_url($url);
+    my $content = $self->fetch_url($url);
+
+    if ($self->opt_c) {
+        $content = JSON::decode_json($content)->{content};
+        $content = "=pod\n\n$content";
+    }
+
+    return $content;
 }
 
 sub scrape_documentation_for {
@@ -63,6 +83,8 @@ sub scrape_documentation_for {
 
     my $content;
     if ($module =~ m{^https?://}) {
+        die "Can't use -c on arbitrary URLs, only module names"
+            if $self->opt_c;
         $content = $self->fetch_url($module);
     }
     else {
@@ -74,7 +96,7 @@ sub scrape_documentation_for {
     $module =~ s/::/-/g;
     my ($fh, $fn) = tempfile(
         "${module}-XXXX",
-        SUFFIX => ".pm",
+        SUFFIX => ($self->opt_c ? ".txt" : ".pm"),
         UNLINK => $self->unlink_tempfiles,
         TMPDIR => 1,
     );
@@ -88,6 +110,10 @@ our $QUERY_CPAN;
 sub grand_search_init {
     my $self = shift;
 
+    if ($self->opt_c) {
+        return $self->scrape_documentation_for($_[0][0]);
+    }
+
     local $QUERY_CPAN = 1;
     return $self->SUPER::grand_search_init(@_);
 }
@@ -130,6 +156,9 @@ Pod::Cpandoc - perldoc that works for modules you don't have installed
     cpandoc Acme::BadExample
         -- works even if you don't have Acme::BadExample installed!
 
+    cpandoc -c Text::Xslate
+        -- shows the changelog file for Text::Xslate
+
     cpandoc -v '$?'
         -- passes everything through to regular perldoc
 
@@ -203,11 +232,11 @@ L<http://sartak.org/talks/yapc-na-2011/cpandoc/>
 
 =head1 AUTHOR
 
-Shawn M Moore C<sartak@gmail.com>
+Shawn M Moore C<code@sartak.org>
 
 =head1 COPYRIGHT
 
-Copyright 2011 Shawn M Moore.
+Copyright 2011-2013 Shawn M Moore.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
